| Copyright | (c) 2013-2018 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay+amazonka@gmail.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | Haskell2010 |
Network.AWS.Greengrass.CreateFunctionDefinitionVersion
Description
Creates a version of a Lambda function definition that has already been defined.
Synopsis
- createFunctionDefinitionVersion :: Text -> CreateFunctionDefinitionVersion
- data CreateFunctionDefinitionVersion
- cfdvAmznClientToken :: Lens' CreateFunctionDefinitionVersion (Maybe Text)
- cfdvFunctions :: Lens' CreateFunctionDefinitionVersion [Function]
- cfdvFunctionDefinitionId :: Lens' CreateFunctionDefinitionVersion Text
- createFunctionDefinitionVersionResponse :: Int -> CreateFunctionDefinitionVersionResponse
- data CreateFunctionDefinitionVersionResponse
- cfdvrsARN :: Lens' CreateFunctionDefinitionVersionResponse (Maybe Text)
- cfdvrsCreationTimestamp :: Lens' CreateFunctionDefinitionVersionResponse (Maybe Text)
- cfdvrsVersion :: Lens' CreateFunctionDefinitionVersionResponse (Maybe Text)
- cfdvrsId :: Lens' CreateFunctionDefinitionVersionResponse (Maybe Text)
- cfdvrsResponseStatus :: Lens' CreateFunctionDefinitionVersionResponse Int
Creating a Request
createFunctionDefinitionVersion Source #
Arguments
| :: Text | |
| -> CreateFunctionDefinitionVersion |
Creates a value of CreateFunctionDefinitionVersion with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
cfdvAmznClientToken- A client token used to correlate requests and responses.cfdvFunctions- A list of Lambda functions in this function definition version.cfdvFunctionDefinitionId- The ID of the Lambda function definition.
data CreateFunctionDefinitionVersion Source #
Information needed to create a function definition version.
See: createFunctionDefinitionVersion smart constructor.
Instances
Request Lenses
cfdvAmznClientToken :: Lens' CreateFunctionDefinitionVersion (Maybe Text) Source #
A client token used to correlate requests and responses.
cfdvFunctions :: Lens' CreateFunctionDefinitionVersion [Function] Source #
A list of Lambda functions in this function definition version.
cfdvFunctionDefinitionId :: Lens' CreateFunctionDefinitionVersion Text Source #
The ID of the Lambda function definition.
Destructuring the Response
createFunctionDefinitionVersionResponse Source #
Creates a value of CreateFunctionDefinitionVersionResponse with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
cfdvrsARN- The ARN of the version.cfdvrsCreationTimestamp- The time, in milliseconds since the epoch, when the version was created.cfdvrsVersion- The unique ID of the version.cfdvrsId- The ID of the version.cfdvrsResponseStatus- -- | The response status code.
data CreateFunctionDefinitionVersionResponse Source #
See: createFunctionDefinitionVersionResponse smart constructor.
Instances
Response Lenses
cfdvrsARN :: Lens' CreateFunctionDefinitionVersionResponse (Maybe Text) Source #
The ARN of the version.
cfdvrsCreationTimestamp :: Lens' CreateFunctionDefinitionVersionResponse (Maybe Text) Source #
The time, in milliseconds since the epoch, when the version was created.
cfdvrsVersion :: Lens' CreateFunctionDefinitionVersionResponse (Maybe Text) Source #
The unique ID of the version.
cfdvrsId :: Lens' CreateFunctionDefinitionVersionResponse (Maybe Text) Source #
The ID of the version.
cfdvrsResponseStatus :: Lens' CreateFunctionDefinitionVersionResponse Int Source #
- - | The response status code.