| Copyright | (c) 2013-2018 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay+amazonka@gmail.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | Haskell2010 |
Network.AWS.Greengrass.CreateResourceDefinition
Description
Creates a resource definition which contains a list of resources to be used in a group. You can create an initial version of the definition by providing a list of resources now, or use 'CreateResourceDefinitionVersion' later.
- createResourceDefinition :: CreateResourceDefinition
- data CreateResourceDefinition
- crdAmznClientToken :: Lens' CreateResourceDefinition (Maybe Text)
- crdInitialVersion :: Lens' CreateResourceDefinition (Maybe ResourceDefinitionVersion)
- crdName :: Lens' CreateResourceDefinition (Maybe Text)
- createResourceDefinitionResponse :: Int -> CreateResourceDefinitionResponse
- data CreateResourceDefinitionResponse
- crdrsLatestVersionARN :: Lens' CreateResourceDefinitionResponse (Maybe Text)
- crdrsARN :: Lens' CreateResourceDefinitionResponse (Maybe Text)
- crdrsName :: Lens' CreateResourceDefinitionResponse (Maybe Text)
- crdrsCreationTimestamp :: Lens' CreateResourceDefinitionResponse (Maybe Text)
- crdrsId :: Lens' CreateResourceDefinitionResponse (Maybe Text)
- crdrsLatestVersion :: Lens' CreateResourceDefinitionResponse (Maybe Text)
- crdrsLastUpdatedTimestamp :: Lens' CreateResourceDefinitionResponse (Maybe Text)
- crdrsResponseStatus :: Lens' CreateResourceDefinitionResponse Int
Creating a Request
createResourceDefinition :: CreateResourceDefinition Source #
Creates a value of CreateResourceDefinition with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
crdAmznClientToken- A client token used to correlate requests and responses.crdInitialVersion- Information about the initial version of the resource definition.crdName- The name of the resource definition.
data CreateResourceDefinition Source #
See: createResourceDefinition smart constructor.
Instances
Request Lenses
crdAmznClientToken :: Lens' CreateResourceDefinition (Maybe Text) Source #
A client token used to correlate requests and responses.
crdInitialVersion :: Lens' CreateResourceDefinition (Maybe ResourceDefinitionVersion) Source #
Information about the initial version of the resource definition.
Destructuring the Response
createResourceDefinitionResponse Source #
Arguments
| :: Int | |
| -> CreateResourceDefinitionResponse |
Creates a value of CreateResourceDefinitionResponse with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
crdrsLatestVersionARN- The ARN of the latest version of the definition.crdrsARN- The ARN of the definition.crdrsName- The name of the definition.crdrsCreationTimestamp- The time, in milliseconds since the epoch, when the definition was created.crdrsId- The ID of the definition.crdrsLatestVersion- The latest version of the definition.crdrsLastUpdatedTimestamp- The time, in milliseconds since the epoch, when the definition was last updated.crdrsResponseStatus- -- | The response status code.
data CreateResourceDefinitionResponse Source #
See: createResourceDefinitionResponse smart constructor.
Instances
Response Lenses
crdrsLatestVersionARN :: Lens' CreateResourceDefinitionResponse (Maybe Text) Source #
The ARN of the latest version of the definition.
crdrsName :: Lens' CreateResourceDefinitionResponse (Maybe Text) Source #
The name of the definition.
crdrsCreationTimestamp :: Lens' CreateResourceDefinitionResponse (Maybe Text) Source #
The time, in milliseconds since the epoch, when the definition was created.
crdrsLatestVersion :: Lens' CreateResourceDefinitionResponse (Maybe Text) Source #
The latest version of the definition.
crdrsLastUpdatedTimestamp :: Lens' CreateResourceDefinitionResponse (Maybe Text) Source #
The time, in milliseconds since the epoch, when the definition was last updated.
crdrsResponseStatus :: Lens' CreateResourceDefinitionResponse Int Source #
- - | The response status code.