| Copyright | (c) 2013-2018 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay+amazonka@gmail.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | Haskell2010 |
Network.AWS.Greengrass.CreateSubscriptionDefinitionVersion
Description
Creates a version of a subscription definition which has already been defined.
- createSubscriptionDefinitionVersion :: Text -> CreateSubscriptionDefinitionVersion
- data CreateSubscriptionDefinitionVersion
- csdvAmznClientToken :: Lens' CreateSubscriptionDefinitionVersion (Maybe Text)
- csdvSubscriptions :: Lens' CreateSubscriptionDefinitionVersion [Subscription]
- csdvSubscriptionDefinitionId :: Lens' CreateSubscriptionDefinitionVersion Text
- createSubscriptionDefinitionVersionResponse :: Int -> CreateSubscriptionDefinitionVersionResponse
- data CreateSubscriptionDefinitionVersionResponse
- csdvrsARN :: Lens' CreateSubscriptionDefinitionVersionResponse (Maybe Text)
- csdvrsCreationTimestamp :: Lens' CreateSubscriptionDefinitionVersionResponse (Maybe Text)
- csdvrsVersion :: Lens' CreateSubscriptionDefinitionVersionResponse (Maybe Text)
- csdvrsId :: Lens' CreateSubscriptionDefinitionVersionResponse (Maybe Text)
- csdvrsResponseStatus :: Lens' CreateSubscriptionDefinitionVersionResponse Int
Creating a Request
createSubscriptionDefinitionVersion Source #
Creates a value of CreateSubscriptionDefinitionVersion with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
csdvAmznClientToken- A client token used to correlate requests and responses.csdvSubscriptions- A list of subscriptions.csdvSubscriptionDefinitionId- The ID of the subscription definition.
data CreateSubscriptionDefinitionVersion Source #
See: createSubscriptionDefinitionVersion smart constructor.
Instances
Request Lenses
csdvAmznClientToken :: Lens' CreateSubscriptionDefinitionVersion (Maybe Text) Source #
A client token used to correlate requests and responses.
csdvSubscriptions :: Lens' CreateSubscriptionDefinitionVersion [Subscription] Source #
A list of subscriptions.
csdvSubscriptionDefinitionId :: Lens' CreateSubscriptionDefinitionVersion Text Source #
The ID of the subscription definition.
Destructuring the Response
createSubscriptionDefinitionVersionResponse Source #
Creates a value of CreateSubscriptionDefinitionVersionResponse with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
csdvrsARN- The ARN of the version.csdvrsCreationTimestamp- The time, in milliseconds since the epoch, when the version was created.csdvrsVersion- The unique ID of the version.csdvrsId- The ID of the version.csdvrsResponseStatus- -- | The response status code.
data CreateSubscriptionDefinitionVersionResponse Source #
See: createSubscriptionDefinitionVersionResponse smart constructor.
Instances
Response Lenses
csdvrsARN :: Lens' CreateSubscriptionDefinitionVersionResponse (Maybe Text) Source #
The ARN of the version.
csdvrsCreationTimestamp :: Lens' CreateSubscriptionDefinitionVersionResponse (Maybe Text) Source #
The time, in milliseconds since the epoch, when the version was created.
csdvrsVersion :: Lens' CreateSubscriptionDefinitionVersionResponse (Maybe Text) Source #
The unique ID of the version.
csdvrsId :: Lens' CreateSubscriptionDefinitionVersionResponse (Maybe Text) Source #
The ID of the version.
csdvrsResponseStatus :: Lens' CreateSubscriptionDefinitionVersionResponse Int Source #
- - | The response status code.