| Copyright | (c) 2013-2018 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay+amazonka@gmail.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | Haskell2010 |
Network.AWS.Greengrass.ListFunctionDefinitionVersions
Description
Lists the versions of a Lambda function definition.
- listFunctionDefinitionVersions :: Text -> ListFunctionDefinitionVersions
- data ListFunctionDefinitionVersions
- lfdvNextToken :: Lens' ListFunctionDefinitionVersions (Maybe Text)
- lfdvMaxResults :: Lens' ListFunctionDefinitionVersions (Maybe Text)
- lfdvFunctionDefinitionId :: Lens' ListFunctionDefinitionVersions Text
- listFunctionDefinitionVersionsResponse :: Int -> ListFunctionDefinitionVersionsResponse
- data ListFunctionDefinitionVersionsResponse
- lfdvrsVersions :: Lens' ListFunctionDefinitionVersionsResponse [VersionInformation]
- lfdvrsNextToken :: Lens' ListFunctionDefinitionVersionsResponse (Maybe Text)
- lfdvrsResponseStatus :: Lens' ListFunctionDefinitionVersionsResponse Int
Creating a Request
listFunctionDefinitionVersions Source #
Arguments
| :: Text | |
| -> ListFunctionDefinitionVersions |
Creates a value of ListFunctionDefinitionVersions with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
lfdvNextToken- The token for the next set of results, or 'null'if there are no additional results.lfdvMaxResults- The maximum number of results to be returned per request.lfdvFunctionDefinitionId- The ID of the Lambda function definition.
data ListFunctionDefinitionVersions Source #
See: listFunctionDefinitionVersions smart constructor.
Instances
Request Lenses
lfdvNextToken :: Lens' ListFunctionDefinitionVersions (Maybe Text) Source #
The token for the next set of results, or 'null' if there are no additional results.
lfdvMaxResults :: Lens' ListFunctionDefinitionVersions (Maybe Text) Source #
The maximum number of results to be returned per request.
lfdvFunctionDefinitionId :: Lens' ListFunctionDefinitionVersions Text Source #
The ID of the Lambda function definition.
Destructuring the Response
listFunctionDefinitionVersionsResponse Source #
Creates a value of ListFunctionDefinitionVersionsResponse with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
lfdvrsVersions- Information about a version.lfdvrsNextToken- The token for the next set of results, or 'null'if there are no additional results.lfdvrsResponseStatus- -- | The response status code.
data ListFunctionDefinitionVersionsResponse Source #
See: listFunctionDefinitionVersionsResponse smart constructor.
Instances
Response Lenses
lfdvrsVersions :: Lens' ListFunctionDefinitionVersionsResponse [VersionInformation] Source #
Information about a version.
lfdvrsNextToken :: Lens' ListFunctionDefinitionVersionsResponse (Maybe Text) Source #
The token for the next set of results, or 'null' if there are no additional results.
lfdvrsResponseStatus :: Lens' ListFunctionDefinitionVersionsResponse Int Source #
- - | The response status code.