| Copyright | (c) 2013-2018 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay+amazonka@gmail.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | Haskell2010 |
Network.AWS.Greengrass.ListFunctionDefinitions
Description
Retrieves a list of Lambda function definitions.
- listFunctionDefinitions :: ListFunctionDefinitions
- data ListFunctionDefinitions
- lfdNextToken :: Lens' ListFunctionDefinitions (Maybe Text)
- lfdMaxResults :: Lens' ListFunctionDefinitions (Maybe Text)
- listFunctionDefinitionsResponse :: Int -> ListFunctionDefinitionsResponse
- data ListFunctionDefinitionsResponse
- lfdrsNextToken :: Lens' ListFunctionDefinitionsResponse (Maybe Text)
- lfdrsDefinitions :: Lens' ListFunctionDefinitionsResponse [DefinitionInformation]
- lfdrsResponseStatus :: Lens' ListFunctionDefinitionsResponse Int
Creating a Request
listFunctionDefinitions :: ListFunctionDefinitions Source #
Creates a value of ListFunctionDefinitions with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
lfdNextToken- The token for the next set of results, or 'null'if there are no additional results.lfdMaxResults- The maximum number of results to be returned per request.
data ListFunctionDefinitions Source #
See: listFunctionDefinitions smart constructor.
Instances
Request Lenses
lfdNextToken :: Lens' ListFunctionDefinitions (Maybe Text) Source #
The token for the next set of results, or 'null' if there are no additional results.
lfdMaxResults :: Lens' ListFunctionDefinitions (Maybe Text) Source #
The maximum number of results to be returned per request.
Destructuring the Response
listFunctionDefinitionsResponse Source #
Arguments
| :: Int | |
| -> ListFunctionDefinitionsResponse |
Creates a value of ListFunctionDefinitionsResponse with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
lfdrsNextToken- The token for the next set of results, or 'null'if there are no additional results.lfdrsDefinitions- Information about a definition.lfdrsResponseStatus- -- | The response status code.
data ListFunctionDefinitionsResponse Source #
See: listFunctionDefinitionsResponse smart constructor.
Instances
Response Lenses
lfdrsNextToken :: Lens' ListFunctionDefinitionsResponse (Maybe Text) Source #
The token for the next set of results, or 'null' if there are no additional results.
lfdrsDefinitions :: Lens' ListFunctionDefinitionsResponse [DefinitionInformation] Source #
Information about a definition.
lfdrsResponseStatus :: Lens' ListFunctionDefinitionsResponse Int Source #
- - | The response status code.