| Copyright | (c) 2013-2018 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay+amazonka@gmail.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | Haskell2010 |
Network.AWS.Greengrass.UpdateFunctionDefinition
Description
Updates a Lambda function definition.
- updateFunctionDefinition :: Text -> UpdateFunctionDefinition
- data UpdateFunctionDefinition
- ufdName :: Lens' UpdateFunctionDefinition (Maybe Text)
- ufdFunctionDefinitionId :: Lens' UpdateFunctionDefinition Text
- updateFunctionDefinitionResponse :: Int -> UpdateFunctionDefinitionResponse
- data UpdateFunctionDefinitionResponse
- ufdrsResponseStatus :: Lens' UpdateFunctionDefinitionResponse Int
Creating a Request
updateFunctionDefinition Source #
Arguments
| :: Text | |
| -> UpdateFunctionDefinition |
Creates a value of UpdateFunctionDefinition with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
ufdName- The name of the definition.ufdFunctionDefinitionId- The ID of the Lambda function definition.
data UpdateFunctionDefinition Source #
See: updateFunctionDefinition smart constructor.
Instances
Request Lenses
ufdFunctionDefinitionId :: Lens' UpdateFunctionDefinition Text Source #
The ID of the Lambda function definition.
Destructuring the Response
updateFunctionDefinitionResponse Source #
Arguments
| :: Int | |
| -> UpdateFunctionDefinitionResponse |
Creates a value of UpdateFunctionDefinitionResponse with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
ufdrsResponseStatus- -- | The response status code.
data UpdateFunctionDefinitionResponse Source #
See: updateFunctionDefinitionResponse smart constructor.
Instances
Response Lenses
ufdrsResponseStatus :: Lens' UpdateFunctionDefinitionResponse Int Source #
- - | The response status code.