| Copyright | (c) 2013-2017 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay+amazonka@gmail.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | Haskell2010 |
Network.AWS.Greengrass.CreateFunctionDefinition
Description
Creates a Lambda function definition which contains a list of Lambda functions and their configurations to be used in a group. You can create an initial version of the definition by providing a list of Lambda functions and their configurations now, or use `CreateFunctionDefinitionVersion` later.
- createFunctionDefinition :: CreateFunctionDefinition
- data CreateFunctionDefinition
- cfdAmznClientToken :: Lens' CreateFunctionDefinition (Maybe Text)
- cfdInitialVersion :: Lens' CreateFunctionDefinition (Maybe FunctionDefinitionVersion)
- cfdName :: Lens' CreateFunctionDefinition (Maybe Text)
- createFunctionDefinitionResponse :: Int -> CreateFunctionDefinitionResponse
- data CreateFunctionDefinitionResponse
- cfdrsLatestVersionARN :: Lens' CreateFunctionDefinitionResponse (Maybe Text)
- cfdrsARN :: Lens' CreateFunctionDefinitionResponse (Maybe Text)
- cfdrsName :: Lens' CreateFunctionDefinitionResponse (Maybe Text)
- cfdrsCreationTimestamp :: Lens' CreateFunctionDefinitionResponse (Maybe Text)
- cfdrsId :: Lens' CreateFunctionDefinitionResponse (Maybe Text)
- cfdrsLatestVersion :: Lens' CreateFunctionDefinitionResponse (Maybe Text)
- cfdrsLastUpdatedTimestamp :: Lens' CreateFunctionDefinitionResponse (Maybe Text)
- cfdrsResponseStatus :: Lens' CreateFunctionDefinitionResponse Int
Creating a Request
createFunctionDefinition :: CreateFunctionDefinition Source #
Creates a value of CreateFunctionDefinition with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
cfdAmznClientToken- The client token used to request idempotent operations.cfdInitialVersion- Information on the initial versioncfdName- name of the function definition
data CreateFunctionDefinition Source #
See: createFunctionDefinition smart constructor.
Instances
Request Lenses
cfdAmznClientToken :: Lens' CreateFunctionDefinition (Maybe Text) Source #
The client token used to request idempotent operations.
cfdInitialVersion :: Lens' CreateFunctionDefinition (Maybe FunctionDefinitionVersion) Source #
Information on the initial version
Destructuring the Response
createFunctionDefinitionResponse Source #
Arguments
| :: Int | |
| -> CreateFunctionDefinitionResponse |
Creates a value of CreateFunctionDefinitionResponse with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
cfdrsLatestVersionARN- Latest version arn of the definition.cfdrsARN- Arn of the definition.cfdrsName- Name of the definition.cfdrsCreationTimestamp- Timestamp of when the definition was created.cfdrsId- Id of the definition.cfdrsLatestVersion- Last version of the definition.cfdrsLastUpdatedTimestamp- Last updated timestamp of the definition.cfdrsResponseStatus- -- | The response status code.
data CreateFunctionDefinitionResponse Source #
See: createFunctionDefinitionResponse smart constructor.
Instances
Response Lenses
cfdrsLatestVersionARN :: Lens' CreateFunctionDefinitionResponse (Maybe Text) Source #
Latest version arn of the definition.
cfdrsCreationTimestamp :: Lens' CreateFunctionDefinitionResponse (Maybe Text) Source #
Timestamp of when the definition was created.
cfdrsLatestVersion :: Lens' CreateFunctionDefinitionResponse (Maybe Text) Source #
Last version of the definition.
cfdrsLastUpdatedTimestamp :: Lens' CreateFunctionDefinitionResponse (Maybe Text) Source #
Last updated timestamp of the definition.
cfdrsResponseStatus :: Lens' CreateFunctionDefinitionResponse Int Source #
- - | The response status code.