| Copyright | (c) 2013-2017 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay+amazonka@gmail.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | Haskell2010 |
Network.AWS.Greengrass.CreateFunctionDefinitionVersion
Description
Create a version of a Lambda function definition that has already been defined.
- createFunctionDefinitionVersion :: Text -> CreateFunctionDefinitionVersion
- data CreateFunctionDefinitionVersion
- cfdvAmznClientToken :: Lens' CreateFunctionDefinitionVersion (Maybe Text)
- cfdvFunctions :: Lens' CreateFunctionDefinitionVersion [Function]
- cfdvFunctionDefinitionId :: Lens' CreateFunctionDefinitionVersion Text
- createFunctionDefinitionVersionResponse :: Int -> CreateFunctionDefinitionVersionResponse
- data CreateFunctionDefinitionVersionResponse
- cfdvrsARN :: Lens' CreateFunctionDefinitionVersionResponse (Maybe Text)
- cfdvrsCreationTimestamp :: Lens' CreateFunctionDefinitionVersionResponse (Maybe Text)
- cfdvrsVersion :: Lens' CreateFunctionDefinitionVersionResponse (Maybe Text)
- cfdvrsId :: Lens' CreateFunctionDefinitionVersionResponse (Maybe Text)
- cfdvrsResponseStatus :: Lens' CreateFunctionDefinitionVersionResponse Int
Creating a Request
createFunctionDefinitionVersion Source #
Arguments
| :: Text | |
| -> CreateFunctionDefinitionVersion |
Creates a value of CreateFunctionDefinitionVersion with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
cfdvAmznClientToken- The client token used to request idempotent operations.cfdvFunctions- Lambda functions in this function definition version.cfdvFunctionDefinitionId- the unique Id of the lambda definition
data CreateFunctionDefinitionVersion Source #
Function definition version
See: createFunctionDefinitionVersion smart constructor.
Instances
Request Lenses
cfdvAmznClientToken :: Lens' CreateFunctionDefinitionVersion (Maybe Text) Source #
The client token used to request idempotent operations.
cfdvFunctions :: Lens' CreateFunctionDefinitionVersion [Function] Source #
Lambda functions in this function definition version.
cfdvFunctionDefinitionId :: Lens' CreateFunctionDefinitionVersion Text Source #
the unique Id of the lambda definition
Destructuring the Response
createFunctionDefinitionVersionResponse Source #
Creates a value of CreateFunctionDefinitionVersionResponse with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
cfdvrsARN- Arn of the version.cfdvrsCreationTimestamp- Timestamp of when the version was created.cfdvrsVersion- Unique Id of a version.cfdvrsId- Id of the resource container.cfdvrsResponseStatus- -- | The response status code.
data CreateFunctionDefinitionVersionResponse Source #
See: createFunctionDefinitionVersionResponse smart constructor.
Instances
Response Lenses
cfdvrsCreationTimestamp :: Lens' CreateFunctionDefinitionVersionResponse (Maybe Text) Source #
Timestamp of when the version was created.
cfdvrsVersion :: Lens' CreateFunctionDefinitionVersionResponse (Maybe Text) Source #
Unique Id of a version.
cfdvrsId :: Lens' CreateFunctionDefinitionVersionResponse (Maybe Text) Source #
Id of the resource container.
cfdvrsResponseStatus :: Lens' CreateFunctionDefinitionVersionResponse Int Source #
- - | The response status code.