| Copyright | (c) 2013-2017 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay+amazonka@gmail.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | Haskell2010 |
Network.AWS.Greengrass.CreateSubscriptionDefinitionVersion
Description
Creates a version of a subscription definition which has already been defined.
- createSubscriptionDefinitionVersion :: Text -> CreateSubscriptionDefinitionVersion
- data CreateSubscriptionDefinitionVersion
- csdvAmznClientToken :: Lens' CreateSubscriptionDefinitionVersion (Maybe Text)
- csdvSubscriptions :: Lens' CreateSubscriptionDefinitionVersion [Subscription]
- csdvSubscriptionDefinitionId :: Lens' CreateSubscriptionDefinitionVersion Text
- createSubscriptionDefinitionVersionResponse :: Int -> CreateSubscriptionDefinitionVersionResponse
- data CreateSubscriptionDefinitionVersionResponse
- csdvrsARN :: Lens' CreateSubscriptionDefinitionVersionResponse (Maybe Text)
- csdvrsCreationTimestamp :: Lens' CreateSubscriptionDefinitionVersionResponse (Maybe Text)
- csdvrsVersion :: Lens' CreateSubscriptionDefinitionVersionResponse (Maybe Text)
- csdvrsId :: Lens' CreateSubscriptionDefinitionVersionResponse (Maybe Text)
- csdvrsResponseStatus :: Lens' CreateSubscriptionDefinitionVersionResponse Int
Creating a Request
createSubscriptionDefinitionVersion Source #
Creates a value of CreateSubscriptionDefinitionVersion with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
csdvAmznClientToken- The client token used to request idempotent operations.csdvSubscriptions- Subscriptions in the version.csdvSubscriptionDefinitionId- subscription definition Id
data CreateSubscriptionDefinitionVersion Source #
See: createSubscriptionDefinitionVersion smart constructor.
Instances
Request Lenses
csdvAmznClientToken :: Lens' CreateSubscriptionDefinitionVersion (Maybe Text) Source #
The client token used to request idempotent operations.
csdvSubscriptions :: Lens' CreateSubscriptionDefinitionVersion [Subscription] Source #
Subscriptions in the version.
csdvSubscriptionDefinitionId :: Lens' CreateSubscriptionDefinitionVersion Text Source #
subscription definition Id
Destructuring the Response
createSubscriptionDefinitionVersionResponse Source #
Creates a value of CreateSubscriptionDefinitionVersionResponse with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
csdvrsARN- Arn of the version.csdvrsCreationTimestamp- Timestamp of when the version was created.csdvrsVersion- Unique Id of a version.csdvrsId- Id of the resource container.csdvrsResponseStatus- -- | The response status code.
data CreateSubscriptionDefinitionVersionResponse Source #
See: createSubscriptionDefinitionVersionResponse smart constructor.
Instances
Response Lenses
csdvrsARN :: Lens' CreateSubscriptionDefinitionVersionResponse (Maybe Text) Source #
Arn of the version.
csdvrsCreationTimestamp :: Lens' CreateSubscriptionDefinitionVersionResponse (Maybe Text) Source #
Timestamp of when the version was created.
csdvrsVersion :: Lens' CreateSubscriptionDefinitionVersionResponse (Maybe Text) Source #
Unique Id of a version.
csdvrsId :: Lens' CreateSubscriptionDefinitionVersionResponse (Maybe Text) Source #
Id of the resource container.
csdvrsResponseStatus :: Lens' CreateSubscriptionDefinitionVersionResponse Int Source #
- - | The response status code.